.new-accent {
    background-color: var(--accent, #00B0FF);
}

.new-accent-light {
    background-color: var(--accent_light);
}

.new-primary {
    background-color: var(--primary, #00695C);
}

.new-secondary {
    background-color: var(--secondary, #26A69A);
}

.font-color{
   color: var(--font-color, #000);
}

.card .card-action{
    width: 100%;
}
